@@ -4,7 +4,7 @@ import os.path
 import aiohttp
 from aiocache import cached
 
-from .exception import ValidateUIDError, UIDNotFounded
+from .exception import *
 from .model import EnkaData
 from .model.artifact import Artifact
 from .model.character import CharacterSkill, CharacterConstellation, CharacterSkillType
@@ -182,11 +182,12 @@ class Enka:
             return ''
 
     @cached(ttl=600)
-    async def fetch_user(self, uid: int) -> EnkaData:
+    async def fetch_user(self, uid: int, player_only=False) -> EnkaData:
         """
         Fetch user data from enka api, resolve text hash if available
 
         :param uid: user in game uid
+        :param player_only: fetch only player info
         :return: EnkaData object referencing player
         """
         if not isinstance(uid, int):
@@ -199,62 +200,81 @@ class Enka:
 
         async with aiohttp.ClientSession(headers={"User-Agent": self.USER_AGENT},
                                          timeout=aiohttp.ClientTimeout(total=self.timeout)) as client:
-            resp = await client.get(self._URL.format(uid=uid), proxy=self.proxy)
+            url = self._URL.format(uid=uid)
+            if player_only:
+                url += '?info'
+            resp = await client.get(url, proxy=self.proxy)
 
             if resp.status != 200:
-                raise UIDNotFounded(f"UID {uid} not found.")
+                if resp.status == 400:
+                    raise WrongUIDFormat(f'Wrong uid format! {uid}')
+                elif resp.status == 404:
+                    raise PlayerDoesNOTExist(f'Player {uid} does not exist')
+                elif resp.status == 424:
+                    raise GameMaintenance('Game in maintenance')
+                elif resp.status == 429:
+                    raise RateLimited('Rate limited')
+                elif resp.status == 500:
+                    raise GeneralServerError('Server error 500')
+                elif resp.status == 503:
+                    raise EnkaError('Enka endpoint error 503')
+                else:
+                    raise EnkaError(f'Unknown error {resp.status}')
 
             data = await resp.json()
 
             if not data:
-                raise UIDNotFounded(f"UID {uid} not found.")
+                raise EnkaError(f'Unknown error[No Data]')
 
         obj: EnkaData = EnkaData.parse_obj(data)
 
-        for character in obj.characters:
-            if character.skill_depot_id in self._skill_depot_data:
-                depot = self._skill_depot_data[character.skill_depot_id]
-                if 'energySkill' in depot:
-                    burst_id = depot['energySkill']
-                    if burst_id in self._skill_data:
-                        cs = CharacterSkill()
-                        cs.id = burst_id
-                        cs.type = CharacterSkillType.ElementalBurst
-                        cs.name_hash = self._skill_data[burst_id]['nameTextMapHash']
-                        cs.icon = self._skill_data[burst_id]['skillIcon']
-                        character.skills.append(cs)
-                for skill_id in depot['skills']:
-                    if skill_id and skill_id in self._skill_data:
-                        skill_info = self._skill_data[skill_id]
-                        cs = CharacterSkill()
-                        cs.id = skill_id
-                        if 'cdTime' in skill_info and skill_info['cdTime']:
-                            cs.type = CharacterSkillType.ElementalSkill
-                        else:
-                            cs.type = CharacterSkillType.NormalSkill
-                        cs.name_hash = skill_info['nameTextMapHash']
-                        cs.icon = self._skill_data[burst_id]['skillIcon']
-                        character.skills.append(cs)
-                for talent_id in depot['talents']:
-                    if talent_id and talent_id in self._talent_data:
-                        talent_info = self._talent_data[talent_id]
-                        tl = CharacterConstellation()
-                        tl.id = talent_id
-                        tl.icon = talent_info['icon']
-                        tl.name_hash = talent_info['nameTextMapHash']
-                        character.constellations.append(tl)
-                character.process_skill()
-                character.activate_constellation()
-            if self.lang and self.lang in self._lang_data and self._lang_data[self.lang] and self._avatar_data:
-                for equip in character.equipList:
-                    equip.flat.nameText = await self.resolve_text_hash(equip.flat.nameTextMapHash, self.lang)
-                    if isinstance(equip, Artifact):
-                        equip.flat.setNameText = await self.resolve_text_hash(equip.flat.setNameTextMapHash, self.lang)
-                if character.id in self._avatar_data:
-                    character.name = await self.resolve_text_hash(self._avatar_data[character.id]['nameTextMapHash'],
-                                                                  self.lang)
-                for skill in character.skills:
-                    skill.name = await self.resolve_text_hash(skill.name_hash, self.lang)
-                for c in character.constellations:
-                    c.name = await self.resolve_text_hash(c.name_hash, self.lang)
+        if not player_only:
+            for character in obj.characters:
+                if character.skill_depot_id in self._skill_depot_data:
+                    depot = self._skill_depot_data[character.skill_depot_id]
+                    if 'energySkill' in depot:
+                        burst_id = depot['energySkill']
+                        if burst_id in self._skill_data:
+                            cs = CharacterSkill()
+                            cs.id = burst_id
+                            cs.type = CharacterSkillType.ElementalBurst
+                            cs.name_hash = self._skill_data[burst_id]['nameTextMapHash']
+                            cs.icon = self._skill_data[burst_id]['skillIcon']
+                            character.skills.append(cs)
+                    for skill_id in depot['skills']:
+                        if skill_id and skill_id in self._skill_data:
+                            skill_info = self._skill_data[skill_id]
+                            cs = CharacterSkill()
+                            cs.id = skill_id
+                            if 'cdTime' in skill_info and skill_info['cdTime']:
+                                cs.type = CharacterSkillType.ElementalSkill
+                            else:
+                                cs.type = CharacterSkillType.NormalSkill
+                            cs.name_hash = skill_info['nameTextMapHash']
+                            cs.icon = self._skill_data[burst_id]['skillIcon']
+                            character.skills.append(cs)
+                    for talent_id in depot['talents']:
+                        if talent_id and talent_id in self._talent_data:
+                            talent_info = self._talent_data[talent_id]
+                            tl = CharacterConstellation()
+                            tl.id = talent_id
+                            tl.icon = talent_info['icon']
+                            tl.name_hash = talent_info['nameTextMapHash']
+                            character.constellations.append(tl)
+                    character.process_skill()
+                    character.activate_constellation()
+                if self.lang and self.lang in self._lang_data and self._lang_data[self.lang] and self._avatar_data:
+                    for equip in character.equipList:
+                        equip.flat.nameText = await self.resolve_text_hash(equip.flat.nameTextMapHash, self.lang)
+                        if isinstance(equip, Artifact):
+                            equip.flat.setNameText = await self.resolve_text_hash(equip.flat.setNameTextMapHash,
+                                                                                  self.lang)
+                    if character.id in self._avatar_data:
+                        character.name = await self.resolve_text_hash(
+                            self._avatar_data[character.id]['nameTextMapHash'],
+                            self.lang)
+                    for skill in character.skills:
+                        skill.name = await self.resolve_text_hash(skill.name_hash, self.lang)
+                    for c in character.constellations:
+                        c.name = await self.resolve_text_hash(c.name_hash, self.lang)
         return obj
